==> jupyterlab_amphi-0.1.4.tar.gz: jupyterlab_amphi-0.1.4/packages/pipeline-components-manager/src/PipelineComponent.tsx <==
import { LabIcon } from '@jupyterlab/ui-components';
import { ComponentItem } from './index';

export function PipelineComponent<T extends ComponentItem>() {

  return class implements ComponentItem {

    public static instance: T;
    public _name: string;
    public _id: string;
    public _type: string;
    public _icon: LabIcon;
    public _default: object;
    public _form: object;

    public constructor() { }

    public static getInstance(): T {
      if (!this.instance) {
        this.instance = new this() as T;
      }
      return this.instance;
    }

    public static get Name() {
      const instance = this.getInstance();
      return instance._name;
    }

    // Static getter for the icon
    public static get Type() {
      const instance = this.getInstance();
      return instance._type;
    }

    // Static getter for the icon
    public static get Icon() {
      const instance = this.getInstance();
      return instance._icon;
    }

    // Static getter for the default config
    public static get Default() {
      const instance = this.getInstance();
      return instance._default;
    }

    // Static getter for the default config
    public static get Form() {
      const instance = this.getInstance();
      return instance._form;
    }
  }
}

export interface ConfigFormProps {
  nodeId: string;
  data: any;
  manager: any;
  store: StoreApi;
  setNodes: any;
}

export interface StoreApi {
  getState: () => { nodeInternals: Map<string, any> };
  // ... other necessary methods and properties
}

==> jupyterlab_amphi-0.4.6.tar.gz: jupyterlab_amphi-0.4.6/packages/pipeline-components-manager/src/PipelineComponent.tsx <==
import { LabIcon } from '@jupyterlab/ui-components';
import { ComponentItem } from './index';

export function PipelineComponent<T extends ComponentItem>() {

  return class implements ComponentItem {

    public static instance: T;
    public _name: string;
    public _id: string;
    public _type: string;
    public _icon: any;
    public _default: object;
    public _form: object;

    public constructor() { }

    public static getInstance(): T {
      if (!this.instance) {
        this.instance = new this() as unknown as T;
      }
      return this.instance;
    }

    public static get Name() {
      const instance = this.getInstance();
      return instance._name;
    }

    public static get Type() {
      const instance = this.getInstance();
      return instance._type;
    }

    // Static getter for the icon
    public static get Icon() {
      const instance = this.getInstance();
      return instance._icon;
    }

    // Static getter for the default config
    public static get Default() {
      const instance = this.getInstance();
      return instance._default;
    }

    // Static getter for the default config
    public static get Form() {
      const instance = this.getInstance();
      return instance._form;
    }
  }
}

export interface ConfigFormProps {
  nodeId: string;
  data: any;
  manager: any;
  store: StoreApi;
  setNodes: any;
}

export interface StoreApi {
  getState: () => { nodeInternals: Map<string, any> };
  // ... other necessary methods and properties
}
